<?php
// Own namespace
namespace Org\Mxchange\CoreFramework\Resolver\Controller;

// Import framework stuff
use Org\Mxchange\CoreFramework\Controller\BaseController;
use Org\Mxchange\CoreFramework\Controller\InvalidControllerException;
use Org\Mxchange\CoreFramework\Resolver\Controller\ControllerResolver;
use Org\Mxchange\CoreFramework\Resolver\Controller\BaseControllerResolver;

// Import SPL stuff
use \InvalidArgumentException;

/**
 * A resolver for resolving controllers locally
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2021 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class ImageControllerResolver extends BaseControllerResolver implements ControllerResolver {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	private function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Set prefix to 'image'
		$this->setClassPrefix('image');
	}

	/**
	 * Creates an instance of a resolver class with a given controller
	 *
	 * @param	$namespace					Namespace to look in
	 * @param	$controllerName				The controller we shall resolve
	 * @return	$resolverInstance			The prepared controller resolver instance
	 * @throws	InvalidArgumentException		Thrown if default controller is not set
	 * @throws	InvalidControllerException	Thrown if default controller is invalid
	 */
	public static final function createImageControllerResolver (string $namespace, string $controllerName) {
		// Create the new instance
		$resolverInstance = new ImageControllerResolver();

		// Are all parameter set and the controller is valid?
		if (empty($namespace)) {
			// Then thrown an exception here
			throw new InvalidArgumentException('Parameter "namespace" is empty');
		} elseif (empty($controllerName)) {
			// Then thrown an exception here
			throw new InvalidArgumentException('Parameter "controllerName" is empty');
		} elseif ($resolverInstance->isControllerValid($namespace, $controllerName) === false) {
			// Invalid controller found
			throw new InvalidControllerException(array($resolverInstance, $controllerName), self::EXCEPTION_INVALID_CONTROLLER);
		}

		// Set controller name
		$resolverInstance->setControllerName($controllerName);

		// Return the prepared instance
		return $resolverInstance;
	}

}
